providers = {
    'gmail': 'gmail.com',
    'google': 'gmail.com',
    'yahoo': 'yahoo.com',
    'outlook': 'outlook.com',
    'proton': 'proton.me',
    'protonmail': 'proton.me',
    'icloud': 'icloud.com',
    'icloudmail': 'icloud.com',
    'aol': 'aol.com',
    'chapar': 'chmail.ir',
    'chaapaar': 'chmail.ir',
    'chmail': 'chmail.ir',
    'mailfa': 'mailfa.com',
    'mihanmail': 'mihanmail.ir',
}
